@@ -6,6 +6,8 @@ DEFAULT_DICT_SHARE = 70
 
 
 SUPPORTED_FILE_TYPES = ['xls', 'xlsx', 'csv', 'xml', 'json', 'jsonl', 'yaml', 'tsv', 'sql', 'bson', 'parquet']
+COMPRESSED_FILE_TYPES = ['gz', 'xz', 'zip', 'lz4', '7z', 'bz2']
+BINARY_FILE_TYPES = ['xls', 'xlsx', 'bson', 'parquet'] + COMPRESSED_FILE_TYPES
 
 DEFAULT_OPTIONS = {'encoding' : 'utf8',
                    'delimiter' : ',',
