@@ -7,19 +7,21 @@ from .cmds.converter import Converter
 from .cmds.selector import Selector
 from .cmds.transformer import Transformer
 from .cmds.analyzer import Analyzer
+from .cmds.statistics import StatProcessor
 from .cmds.textproc import TextProcessor
 from .cmds.validator import Validator
 from .cmds.schemer import Schemer
+from .cmds.query import DataQuery
 
 #logging.getLogger().addHandler(logging.StreamHandler())
 logging.basicConfig(
     format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-    level=logging.DEBUG)
+    level=logging.INFO)
 
 def enableVerbose():
     logging.basicConfig(
         format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-        level=logging.DEBUG)
+        level=logging.INFO)
 
 
 @click.group()
@@ -151,8 +153,8 @@ def stats(input, output, dictshare, format_in, format_out, delimiter, verbose, z
     options['delimiter'] = delimiter
     options['checkdates'] = checkdates
     options['verbose'] = verbose
-    acmd = Analyzer(nodates=not checkdates)
-    acmd.analyze(input, options)
+    acmd = StatProcessor(nodates=not checkdates)
+    acmd.stats(input, options)
     pass
 
 
@@ -165,9 +167,10 @@ def cli5():
 @click.option('--output', '-o', 'output', default=None, help='Output to this file')
 @click.option('--delimiter', '-d', default=',', help="CSV delimiter if convert from CSV")
 @click.option('--encoding', '-e', default='utf8', help="Input and output encoding")
+@click.option('--format-in',  default=None, help="Format of input file, if set, replaces autodetect")
 @click.option('--filter',  default=None, help="Filter input file with dict query")
 @click.option('--verbose', '-v', count=True, help='Verbose output. Print additional info on command execution')
-def flatten(input, output, delimiter, encoding, filter, verbose):
+def flatten(input, output, delimiter, encoding, format_in, filter, verbose):
     """Flatten data records. Write them as one value per row"""
     if verbose:
         enableVerbose()
@@ -175,6 +178,7 @@ def flatten(input, output, delimiter, encoding, filter, verbose):
     options['delimiter'] = delimiter
     options['output'] = output
     options['encoding'] = encoding
+    options['format_in'] = format_in
     options['filter'] = filter
     acmd = TextProcessor()
     acmd.flatten(input, options)
@@ -364,7 +368,7 @@ def cli11():
 @click.option('-z', '--zipfile', 'zipfile', is_flag=True, help="Used to say input file is .zip file and that data file is inside")
 @click.option('--stype',  default='cerberus', help="Type of the schema: cerberus")
 def scheme(input, output, delimiter, encoding, verbose, format_in, zipfile, stype):
-    """Runs script against each record of input file"""
+    """Generate data schema from file"""
     if verbose:
         enableVerbose()
     options = {}
@@ -379,7 +383,61 @@ def scheme(input, output, delimiter, encoding, verbose, format_in, zipfile, styp
     pass
 
 
-cli = click.CommandCollection(sources=[cli1, cli2, cli3, cli4, cli5, cli6, cli7, cli8, cli9, cli10, cli11])
+@click.group()
+def cli12():
+    pass
+
+@cli12.command()
+@click.argument('input')
+@click.option('--verbose', '-v', count=True, help='Verbose output. Print additional info on command execution')
+@click.option('--format-in',  default=None, help="Format of input file, if set, replaces autodetect")
+@click.option('-z', '--zipfile', 'zipfile', is_flag=True, help="Used to say input file is .zip file and that data file is inside")
+def analyze(input, verbose, format_in, zipfile):
+    """Analyzes given data file and returns human readable insights about it"""
+    if verbose:
+        enableVerbose()
+    options = {}
+    options['format_in'] = format_in
+    options['zipfile'] = zipfile
+    acmd = Analyzer()
+    acmd.analyze(input, options)
+    pass
+
+@click.group()
+def cli13():
+    pass
+
+@cli13.command()
+@click.argument('input')
+@click.option('--output', '-o', 'output', default=None, help='Output to this file')
+@click.option('--delimiter', '-d', default=None, help="CSV delimiter if convert from CSV")
+@click.option('--encoding', '-e', default=None, help="Input and output encoding")
+@click.option('--fields', '-f', default=None, help="Fieldnames, delimiter by ','")
+@click.option('--verbose', '-v', count=True, help='Verbose output. Print additional info on command execution')
+@click.option('--format-in',  default=None, help="Format of input file, if set, replaces autodetect")
+@click.option('--format-out',  default=None, help="Format of output file, if set, replaces autodetect")
+@click.option('-z', '--zipfile', 'zipfile', is_flag=True, help="Used to say input file is .zip file and that data file is inside")
+@click.option('--query', '-q',  default=None, help="Query using mistql")
+def query(input, output, fields, delimiter, encoding, verbose, format_in, format_out, zipfile, query):
+    """Query data using mistql (experimental, require mistql). Use 'pip install mistql' to install"""
+    if verbose:
+        enableVerbose()
+    options = {}
+    options['delimiter'] = delimiter
+    options['fields'] = fields
+    options['output'] = output
+    options['encoding'] = encoding
+    options['format_in'] = format_in
+    options['format_out'] = format_out
+    options['zipfile'] = zipfile
+    options['query'] = query
+    acmd = DataQuery()
+    acmd.query(input, options)
+    pass
+
+
+
+cli = click.CommandCollection(sources=[cli1, cli2, cli3, cli4, cli5, cli6, cli7, cli8, cli9, cli10, cli11, cli12, cli13])
 
 #if __name__ == '__main__':
 #    cli()
